@@ -356,7 +356,7 @@ AGES: while( !$DONE && @AGES ) {
             }
         });
         $duration += time - $start;
-        last unless @{ $result->{hits}{hits} } > 0;
+        last unless $result->{hits} && $result->{hits}{hits} && @{ $result->{hits}{hits} } > 0
     }
     last if all_records_displayed();
 }
@@ -470,7 +470,7 @@ es-search.pl - Provides a CLI for quick searches of data in ElasticSearch daily
 
 =head1 VERSION
 
-version 4.6
+version 4.7
 
 =head1 SYNOPSIS
 
